@@ -125,29 +125,35 @@ def is_usd_like_coin(coin) -> bool:
 def resolve_sub_portfolios(
     master_portfolio: personal_data.SubPortfolioData,
     sub_portfolios: list[personal_data.SubPortfolioData],
-    allowed_filling_assets: list[str],
-    forbidden_filling_assets: list[str],
     market_prices: dict[str, float],
 ) -> (personal_data.SubPortfolioData, list[personal_data.SubPortfolioData]):
-    return personal_data.resolve_sub_portfolios(
-        master_portfolio, sub_portfolios, allowed_filling_assets, forbidden_filling_assets, market_prices
-    )
+    return personal_data.resolve_sub_portfolios(master_portfolio, sub_portfolios, market_prices)
 
 
 def get_portfolio_filled_orders_deltas(
     previous_portfolio_content: dict[str, dict[str, decimal.Decimal]],
     updated_portfolio_content: dict[str, dict[str, decimal.Decimal]],
-    filled_orders: list[personal_data.Order]
-) -> (dict[str, dict[str, decimal.Decimal]], dict[str, dict[str, decimal.Decimal]]):
+    filled_or_partially_filled_orders: list[personal_data.Order],
+    unknown_filled_or_cancelled_orders: list[personal_data.Order],
+    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal]
+) -> personal_data.ResolvedOrdersPortoflioDelta:
     return personal_data.get_portfolio_filled_orders_deltas(
-        previous_portfolio_content, updated_portfolio_content, filled_orders
+        previous_portfolio_content, updated_portfolio_content, 
+        filled_or_partially_filled_orders, unknown_filled_or_cancelled_orders, 
+        ignored_filled_quantity_per_order_exchange_id
     )
 
 
 def get_assets_delta_from_orders(
-    orders: list[personal_data.Order]
+    orders: list[personal_data.Order],
+    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal],
+    compute_forecasted_fees: bool = True,
+    force_fully_filled_orders: bool = False
 ) -> (dict[str, decimal.Decimal], dict[str, decimal.Decimal], dict[str, decimal.Decimal]):
-    return personal_data.get_assets_delta_from_orders(orders)
+    return personal_data.get_assets_delta_from_orders(
+        orders, ignored_filled_quantity_per_order_exchange_id, compute_forecasted_fees, 
+        force_fully_filled_orders=force_fully_filled_orders
+    )
 
 
 def get_accepted_missed_deltas(
