@@ -16,12 +16,14 @@
 import copy
 import decimal
 import typing
+import itertools
 
 import octobot_trading.personal_data.portfolios.asset as asset
 import octobot_trading.personal_data.portfolios.assets
 import octobot_trading.personal_data.orders.order as order_import
 import octobot_trading.personal_data.orders.order_util as order_util
 import octobot_trading.personal_data.portfolios.sub_portfolio_data as sub_portfolio_data
+import octobot_trading.personal_data.portfolios.resolved_orders_portfolio_delta as resolved_orders_portfolio_delta
 import octobot_trading.constants as constants
 import octobot_trading.enums as enums
 import octobot_trading.errors as errors
@@ -258,16 +260,12 @@ def get_asset_price_from_converter_or_tickers(
 def resolve_sub_portfolios(
     master_portfolio: sub_portfolio_data.SubPortfolioData,
     sub_portfolios: list[sub_portfolio_data.SubPortfolioData],
-    allowed_filling_assets: list[str],
-    forbidden_filling_assets: list[str],
     market_prices: dict[str, float],
 ) -> (sub_portfolio_data.SubPortfolioData, list[sub_portfolio_data.SubPortfolioData]):
     resolved_portfolios = []
     remaining_master_portfolio = copy.deepcopy(master_portfolio)
     for sub_portfolio in sorted(sub_portfolios, key=lambda x: x.priority_key):
-        resolved_portfolio = _resolve_sub_portfolio(
-            remaining_master_portfolio, sub_portfolio, allowed_filling_assets, forbidden_filling_assets, market_prices
-        )
+        resolved_portfolio = _resolve_sub_portfolio(remaining_master_portfolio, sub_portfolio, market_prices)
         resolved_portfolios.append(resolved_portfolio)
     return remaining_master_portfolio, resolved_portfolios
 
@@ -275,8 +273,6 @@ def resolve_sub_portfolios(
 def _resolve_sub_portfolio(
     remaining_master_portfolio: sub_portfolio_data.SubPortfolioData,
     sub_portfolio: sub_portfolio_data.SubPortfolioData,
-    allowed_filling_assets: list[str],
-    forbidden_filling_assets: list[str],
     market_prices: dict[str, float],
 ) -> sub_portfolio_data.SubPortfolioData:
     resolved_content = {}
@@ -287,14 +283,14 @@ def _resolve_sub_portfolio(
     for asset_name, holdings in forecasted_sub_portfolio_content.items():
         missing_amount_in_asset = _resolve_sub_portfolio_asset(
             asset_name, holdings, remaining_master_portfolio, resolved_content,
-            sub_portfolio.locked_funds_by_asset.get(asset_name, constants.ZERO), forbidden_filling_assets
+            sub_portfolio.locked_funds_by_asset.get(asset_name, constants.ZERO), sub_portfolio.forbidden_filling_assets
         )
         if missing_amount_in_asset > constants.ZERO:
             missing_amount_by_asset[asset_name] = missing_amount_in_asset
     # now that assets have been allocated, try to compensate missing assets
     for asset_name, missing_amount_in_asset in missing_amount_by_asset.items():
         _fill_missing_assets_from_allowed_filling_assets(
-            asset_name, allowed_filling_assets, market_prices,
+            asset_name, sub_portfolio.allowed_filling_assets, market_prices,
             remaining_master_portfolio, missing_amount_in_asset,
             resolved_content, funds_deltas, missing_funds
         )
@@ -305,8 +301,9 @@ def _resolve_sub_portfolio(
         sub_portfolio.priority_key,
         resolved_content,
         sub_portfolio.unit,
-        funds_deltas,
-        missing_funds,
+        funds_deltas=funds_deltas,
+        missing_funds=missing_funds,
+        locked_funds_by_asset=sub_portfolio.locked_funds_by_asset,
     )
 
 
@@ -424,6 +421,7 @@ def _fill_missing_assets_from_allowed_filling_assets(
                     commons_constants.PORTFOLIO_TOTAL: funds_to_add_in_filling_asset,
                     commons_constants.PORTFOLIO_AVAILABLE: funds_to_add_in_filling_asset,
                 }
+            # register filling assets in funds_deltas
             if filling_asset in funds_deltas:
                 funds_deltas[filling_asset][commons_constants.PORTFOLIO_TOTAL] += funds_to_add_in_filling_asset
                 funds_deltas[filling_asset][commons_constants.PORTFOLIO_AVAILABLE] += funds_to_add_in_filling_asset
@@ -544,16 +542,190 @@ def get_missing_master_portfolio_values_update(
 def get_portfolio_filled_orders_deltas(
     previous_portfolio_content: dict[str, dict[str, decimal.Decimal]],
     updated_portfolio_content: dict[str, dict[str, decimal.Decimal]],
-    filled_orders: list[order_import.Order]
-) -> (dict[str, dict[str, decimal.Decimal]], dict[str, dict[str, decimal.Decimal]]):
-    orders_asset_deltas, expected_fee_related_deltas, possible_fees_asset_deltas = get_assets_delta_from_orders(filled_orders)
+    filled_or_partially_filled_orders: list[order_import.Order],
+    unknown_filled_or_cancelled_orders: list[order_import.Order],
+    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal]
+) -> resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta:
     portfolios_asset_deltas = _get_assets_delta_from_portfolio(previous_portfolio_content, updated_portfolio_content)
-    # return portfolio asset deltas that can approximately be explained by given orders
+    if unknown_filled_or_cancelled_orders:
+        return _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders(
+            filled_or_partially_filled_orders, portfolios_asset_deltas, 
+            unknown_filled_or_cancelled_orders, ignored_filled_quantity_per_order_exchange_id
+        )
+    else:
+        orders_asset_deltas, expected_fee_related_deltas, possible_fees_asset_deltas = get_assets_delta_from_orders(
+            filled_or_partially_filled_orders, ignored_filled_quantity_per_order_exchange_id, True
+        )
+        return compute_assets_deltas_from_orders(
+            orders_asset_deltas, expected_fee_related_deltas, possible_fees_asset_deltas, 
+            portfolios_asset_deltas, allow_portfolio_delta_shrinking=True
+        )
+
+
+def _reverse_portfolio_deltas(
+    portfolios_asset_deltas: dict[str, dict[str, decimal.Decimal]],
+) -> dict[str, dict[str, decimal.Decimal]]:
+    return {
+        asset_name: {
+            key: -delta_values[key] for key in delta_values
+        }
+        for asset_name, delta_values in portfolios_asset_deltas.items()
+    }
+
+
+def _can_orders_compensate_each_other(unknown_filled_or_cancelled_orders: list[order_import.Order]) -> bool:
+    # check if the orders can compensate each other
+    # compensation means that the orders have the same symbol and opposite sides
+    symbols_with_buy_orders = set(
+        order.symbol for order in unknown_filled_or_cancelled_orders if order.side is enums.TradeOrderSide.BUY
+    )
+    symbols_with_sell_orders = set(
+        order.symbol for order in unknown_filled_or_cancelled_orders if order.side is enums.TradeOrderSide.SELL
+    )
+    return bool(symbols_with_buy_orders.intersection(symbols_with_sell_orders))
+
+
+def _get_optimistic_order_counts_to_fill(unknown_filled_or_cancelled_orders: list[order_import.Order]) -> list[int]:
+    # try to avoid iterating all possitibilies when possible. Worse cases are when 50% of the orders are 
+    # filled (their possible combinations are really numerous), process those cases last.
+    # start at 1 to avoid considering no filled orders (already considered in best_inferred_resolved_delta)
+    all_possibilities = list(range(1, len(unknown_filled_or_cancelled_orders) + 1))
+    sorted_orders_to_fill_counts = []
+    for index in range(len(all_possibilities) // 2):
+        # 1. add most filled orders counts
+        sorted_orders_to_fill_counts.append(all_possibilities[-(index + 1)])
+        # 2. add least filled orders counts
+        sorted_orders_to_fill_counts.append(all_possibilities[index])
+    if len(all_possibilities) % 2 == 1:
+        # last: add middle filled orders count if any
+        sorted_orders_to_fill_counts.append(all_possibilities[len(all_possibilities) // 2])
+    return sorted_orders_to_fill_counts
+
+
+def _compute_most_probable_assets_deltas_from_orders_considering_unknown_orders(
+    filled_or_partially_filled_orders: list[order_import.Order],
+    portfolios_asset_deltas: dict[str, dict[str, decimal.Decimal]],
+    unknown_filled_or_cancelled_orders: list[order_import.Order],
+    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal]
+) -> resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta:
+    """
+    Returns the most probable deltas which are the ones that can be best explained by given orders
+    """
+    if filled_or_partially_filled_orders:
+        orders_asset_deltas, expected_fee_related_deltas, possible_fees_asset_deltas = get_assets_delta_from_orders(
+            filled_or_partially_filled_orders, ignored_filled_quantity_per_order_exchange_id, True
+        )
+        known_filled_orders_resolved_delta = compute_assets_deltas_from_orders(
+            orders_asset_deltas, expected_fee_related_deltas, possible_fees_asset_deltas, 
+            portfolios_asset_deltas, 
+            allow_portfolio_delta_shrinking=False, 
+            allow_mixed_sign_delta=True,
+            register_missed_partial_delta_as_ignored=True, 
+            ignore_order_unrelated_deltas=False,
+            ignore_order_extra_deltas=False,
+        )
+    else:
+        known_filled_orders_resolved_delta = resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta()
+    # init with all cancelled orders and explained+unexplained portfolio deltas from known filled orders
+    best_inferred_resolved_delta = resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta(
+        inferred_cancelled_orders=unknown_filled_or_cancelled_orders,
+    ).merge_order_deltas(known_filled_orders_resolved_delta, portfolios_asset_deltas)
+    if (
+        not best_inferred_resolved_delta.unexplained_orders_deltas 
+        and not _can_orders_compensate_each_other(unknown_filled_or_cancelled_orders)
+    ):
+        # all orders are cancelled: stop here
+        return _get_cleared_inferred_resolved_delta(
+            best_inferred_resolved_delta, portfolios_asset_deltas
+        )
+    post_filled_orders_portfolio_asset_deltas = resolved_orders_portfolio_delta.filter_empty_deltas(
+        sub_portfolio_data.get_content_after_deltas(
+            portfolios_asset_deltas, _reverse_portfolio_deltas(
+                best_inferred_resolved_delta.explained_orders_deltas
+            ), apply_available_deltas=True
+        )
+    )
+    sorted_orders_to_fill_counts = _get_optimistic_order_counts_to_fill(unknown_filled_or_cancelled_orders)
+    compute_forecasted_fees = False # don't compute forecasted fees as it will 10x the time to compute the deltas
+    for orders_to_fill_count in sorted_orders_to_fill_counts:
+        for filled_orders_combination in itertools.combinations(unknown_filled_or_cancelled_orders, orders_to_fill_count):
+            potential_filled_orders_combination = list(filled_orders_combination)
+            orders_asset_deltas, expected_fee_related_deltas, possible_fees_asset_deltas = get_assets_delta_from_orders(
+                potential_filled_orders_combination, ignored_filled_quantity_per_order_exchange_id, 
+                compute_forecasted_fees, force_fully_filled_orders=True
+            )
+            if any(
+                asset_name not in post_filled_orders_portfolio_asset_deltas
+                for asset_name in orders_asset_deltas
+            ):
+                # at least one of the candidate filled orders is not related to portfolio delta: skip this combination
+                continue
+            inferred_resolved_delta_candidate = compute_assets_deltas_from_orders(
+                orders_asset_deltas, expected_fee_related_deltas, possible_fees_asset_deltas, 
+                post_filled_orders_portfolio_asset_deltas, 
+                allow_portfolio_delta_shrinking=False, 
+                register_missed_partial_delta_as_ignored=True, 
+                ignore_order_unrelated_deltas=False,
+                ignore_order_extra_deltas=True,
+            )
+            if not inferred_resolved_delta_candidate.adds_explanations():
+                # no added explanations: skip this combination
+                continue
+            merged_inferred_resolved_delta_candidate = inferred_resolved_delta_candidate.merge_order_deltas(
+                known_filled_orders_resolved_delta, portfolios_asset_deltas
+            )
+            merged_inferred_resolved_delta_candidate.inferred_filled_orders = potential_filled_orders_combination
+            merged_inferred_resolved_delta_candidate.inferred_cancelled_orders = [
+                order for order in unknown_filled_or_cancelled_orders if order not in potential_filled_orders_combination
+            ]
+            try:
+                if merged_inferred_resolved_delta_candidate.is_fully_explained():
+                    return _get_cleared_inferred_resolved_delta(
+                        merged_inferred_resolved_delta_candidate, portfolios_asset_deltas
+                    )
+                elif merged_inferred_resolved_delta_candidate.is_more_probable_than(best_inferred_resolved_delta):
+                    best_inferred_resolved_delta = merged_inferred_resolved_delta_candidate
+            except KeyError as err:
+                # should not happen, catch it to avoid raising it if it does
+                commons_logging.get_logger(__name__).error(
+                    f"Unexpected error when computing most probable assets deltas from orders: {err}"
+                )
+    return _get_cleared_inferred_resolved_delta(best_inferred_resolved_delta, portfolios_asset_deltas)
+
+
+def _get_cleared_inferred_resolved_delta(
+    resolved_delta: resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta,
+    portfolios_asset_deltas: dict[str, dict[str, decimal.Decimal]],
+) -> resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta:
+    # clear partial deltas as they should not be considered real deltas (they are due to other "unknown" orders)
+    resolved_delta.ensure_max_delta_and_clear_irrelevant_deltas(portfolios_asset_deltas)
+    return resolved_delta
+
+
+def compute_assets_deltas_from_orders(
+    orders_asset_deltas: dict[str, decimal.Decimal], 
+    expected_fee_related_deltas: dict[str, decimal.Decimal], 
+    possible_fees_asset_deltas: dict[str, decimal.Decimal],
+    portfolios_asset_deltas: dict[str, dict[str, decimal.Decimal]],
+    allow_portfolio_delta_shrinking: bool = True,
+    allow_mixed_sign_delta: bool = False,
+    register_missed_partial_delta_as_ignored: bool = False,
+    ignore_order_unrelated_deltas: bool = True,
+    ignore_order_extra_deltas: bool = False,
+) -> resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta:
+    """
+    returns portfolio asset deltas that can approximately be explained by given orders
+    """
     orders_linked_deltas = {}
     ignored_deltas = {}
     for asset_name, holdings_delta in portfolios_asset_deltas.items():
         if asset_name not in orders_asset_deltas:
-            # this delta is not due to these orders: skip it
+            if ignore_order_unrelated_deltas:
+                # this delta is not due to these orders: skip it
+                continue
+            else:
+                # this delta is not due to these orders: add it to ignored deltas
+                ignored_deltas[asset_name] = holdings_delta
             continue
         order_asset_delta = orders_asset_deltas[asset_name]
         holding_total = holdings_delta[commons_constants.PORTFOLIO_TOTAL]
@@ -569,7 +741,13 @@ def get_portfolio_filled_orders_deltas(
                 * min_allowed_equivalent_total_holding < 0
         ):
             # different sign: incompatible, this is unexpected
-            ignored_deltas[asset_name] = holdings_delta
+            if allow_mixed_sign_delta:
+                orders_linked_deltas[asset_name] = {
+                    key: order_asset_delta
+                    for key in holdings_delta
+                }
+            else:
+                ignored_deltas[asset_name] = holdings_delta
         elif (
             # approx same value
             abs(min_allowed_equivalent_total_holding)
@@ -609,10 +787,18 @@ def get_portfolio_filled_orders_deltas(
             if (
                 # try while taking possible fees into account
                 asset_name in possible_fees_asset_deltas and (
-                    abs(min_allowed_equivalent_total_holding)
-                    # fees bring back the order delta into the expected portfolio delta window
-                    < abs(order_asset_delta + possible_fees_asset_deltas[asset_name])
-                    < abs(max_allowed_equivalent_total_holding)
+                    any(
+                        abs(min_allowed_equivalent_total_holding)
+                        # fees bring back the order delta into the expected portfolio delta window
+                        < abs(order_asset_delta + possible_fee)
+                        < abs(max_allowed_equivalent_total_holding)
+                        for possible_fee in (
+                            # try with smaller fees in case user is paying less fees (when having large volume)
+                            # test from 10% up to 100% fees
+                            possible_fees_asset_deltas[asset_name] * decimal.Decimal(multiplier / 10)
+                            for multiplier in range(1, 11)
+                        )
+                    )
                 )
             ):
                 orders_linked_deltas[asset_name] = holdings_delta
@@ -622,35 +808,58 @@ def get_portfolio_filled_orders_deltas(
                 # Add it to ignored_deltas
                 ignored_deltas[asset_name] = holdings_delta
         elif abs(min_allowed_equivalent_total_holding) > abs(order_asset_delta):
-            # too much in portfolio delta: only take what is linked to the orders deltas
-            # => updates both total and available
-            # Should very rarely happen as it might reduce the total portfolio if done when unecessary
-            commons_logging.get_logger(__name__).warning(
-                f"Too large portfolio {asset_name} delta: {holdings_delta}, reducing to order delta: {order_asset_delta}"
+            # too much in portfolio delta
+            if register_missed_partial_delta_as_ignored:
+                # Partial deltas: only take what is linked to the orders deltas
+                # => updates both total and available
+                orders_linked_deltas[asset_name] = {
+                    key: order_asset_delta
+                    for key in holdings_delta
+                }
+                # register extra delta as ignored
+                ignored_deltas[asset_name] = {
+                    key: pf_delta - order_asset_delta if abs(pf_delta - order_asset_delta) > constants.ZERO else constants.ZERO
+                    for key, pf_delta in holdings_delta.items()
+                }
+            elif allow_portfolio_delta_shrinking:
+                # Only take what is linked to the orders deltas and ignore extra delta values (shrink portfolio deltas)
+                # => updates both total and available
+                # Should very rarely happen as it might reduce the total portfolio if done when unecessary
+                commons_logging.get_logger(__name__).warning(
+                    f"Too large portfolio {asset_name} delta: {holdings_delta}, reducing to order delta: {order_asset_delta}"
+                )
+                orders_linked_deltas[asset_name] = {
+                    key: order_asset_delta
+                    for key in holdings_delta
+                }
+            else:
+                # can't be from those orders: ignore this delta
+                ignored_deltas[asset_name] = holdings_delta
+
+    if not ignore_order_extra_deltas:
+        # consider order deltas that are seen in portfolio deltas
+        for asset_name, order_delta in orders_asset_deltas.items():
+            can_have_no_delta = (
+                (order_delta == constants.ZERO)
+                or (order_delta + possible_fees_asset_deltas.get(asset_name, constants.ZERO)) == constants.ZERO
+                or (order_delta - possible_fees_asset_deltas.get(asset_name, constants.ZERO)) == constants.ZERO
             )
-            orders_linked_deltas[asset_name] = {
-                key: order_asset_delta
-                for key in holdings_delta
-            }
-    for asset_name, order_delta in orders_asset_deltas.items():
-        can_have_no_delta = (
-            (order_delta == constants.ZERO)
-            or (order_delta + possible_fees_asset_deltas.get(asset_name, constants.ZERO)) == constants.ZERO
-            or (order_delta - possible_fees_asset_deltas.get(asset_name, constants.ZERO)) == constants.ZERO
-        )
-        if asset_name not in portfolios_asset_deltas and not can_have_no_delta:
-            # asset not in portfolio delta, this is unexpected, register it in ignored deltas
-            ignored_deltas[asset_name] = {
-                commons_constants.PORTFOLIO_TOTAL: order_delta,
-                commons_constants.PORTFOLIO_AVAILABLE: order_delta
-            }
-    return orders_linked_deltas, ignored_deltas
+            if asset_name not in portfolios_asset_deltas and not can_have_no_delta:
+                # asset not in portfolio delta, this is unexpected, register it in ignored deltas
+                ignored_deltas[asset_name] = {
+                    commons_constants.PORTFOLIO_TOTAL: order_delta,
+                    commons_constants.PORTFOLIO_AVAILABLE: order_delta
+                }
+    return resolved_orders_portfolio_delta.ResolvedOrdersPortoflioDelta(
+        explained_orders_deltas=orders_linked_deltas,
+        unexplained_orders_deltas=ignored_deltas
+    )
 
 
 def _get_assets_delta_from_portfolio(
     previous_portfolio_content: dict,
     updated_portfolio_content: dict,
-) ->  dict[str, dict[str, decimal.Decimal]]:
+) -> dict[str, dict[str, decimal.Decimal]]:
     asset_deltas = {}
     for asset_name in set(previous_portfolio_content).union(updated_portfolio_content):
         if previous_portfolio_content.get(asset_name) != updated_portfolio_content.get(asset_name):
@@ -668,55 +877,152 @@ def _get_assets_delta_from_portfolio(
     return asset_deltas
 
 
-def get_assets_delta_from_orders(orders: list[order_import.Order]) -> (
+def get_assets_delta_from_orders(
+    orders: list[order_import.Order], 
+    ignored_filled_quantity_per_order_exchange_id: dict[str, decimal.Decimal],
+    compute_forecasted_fees: bool,
+    force_fully_filled_orders: bool = False,
+) -> tuple[
     dict[str, decimal.Decimal], dict[str, decimal.Decimal], dict[str, decimal.Decimal]
-):
+]:
     asset_deltas = {}
     expected_fee_related_deltas = {}
     possible_fee_related_deltas = {}
+    exchange_local_fees_currency_price = _get_exchange_local_fees_currency_price(orders) if compute_forecasted_fees else None
     for order in orders:
         base, quote = symbol_util.parse_symbol(order.symbol).base_and_quote()
         # order "expected" related deltas
-        added_unit_and_amount = (
-            (base, order.origin_quantity)
-            if order.side is enums.TradeOrderSide.BUY else (quote, order.total_cost)
-        )
-        removed_unit_and_amount = (
-            (quote, order.total_cost)
-            if order.side is enums.TradeOrderSide.BUY else (base, order.origin_quantity)
-        )
+        ignored_filled_quantity = ignored_filled_quantity_per_order_exchange_id.get(order.exchange_order_id)
+        # For 0 amout filled orders, use origin quantity as we know they are either fully filled or not filled at all.
+        # For partially filled orders, use filled quantity as we know they are partially filled.
+        considered_quantity = order.filled_quantity if (order.filled_quantity and not force_fully_filled_orders) else order.origin_quantity
+        delta_quantity = (considered_quantity - ignored_filled_quantity) if ignored_filled_quantity else considered_quantity
+        if delta_quantity < constants.ZERO:
+            commons_logging.get_logger(__name__).error(
+                f"Invalid delta quantity: {delta_quantity} for order "
+                f"{order.exchange_order_id} on {order.symbol} "
+                f"ignored filled quantity: {ignored_filled_quantity}."
+            )
+            continue
+        if delta_quantity == constants.ZERO:
+            commons_logging.get_logger(__name__).info(
+                f"Skipped zero delta quantity: {delta_quantity} for order "
+                f"{order.exchange_order_id} on {order.symbol} "
+                f"ignored filled quantity: {ignored_filled_quantity}."
+            )
+            continue
+        if order.side is enums.TradeOrderSide.BUY:
+            added_unit_and_amount = (base, delta_quantity)
+            removed_unit_and_amount = (quote, order.get_cost(delta_quantity))
+        elif order.side is enums.TradeOrderSide.SELL:
+            added_unit_and_amount = (quote, order.get_cost(delta_quantity))
+            removed_unit_and_amount = (base, delta_quantity)
+        else:
+            raise ValueError(f"Invalid order side: {order.side}")
         for unit_and_amount, multiplier in zip(
             (added_unit_and_amount, removed_unit_and_amount),
-            (1, -1)
+            (decimal.Decimal(1), decimal.Decimal(-1))
         ):
             if unit_and_amount[0] not in asset_deltas:
                 asset_deltas[unit_and_amount[0]] = unit_and_amount[1] * multiplier
             else:
                 asset_deltas[unit_and_amount[0]] += unit_and_amount[1] * multiplier
-        # order "probable" related deltas (account for worse case fees)
-        expected_forecasted_fees = order.get_computed_fee(use_origin_quantity_and_price=True)
-        possible_forecasted_fees = _get_other_asset_forecasted_fees(order, expected_forecasted_fees)
-        for fee_asset in (base, quote):
-            for fee in (expected_forecasted_fees, possible_forecasted_fees):
-                is_expected_fee = fee is expected_forecasted_fees
-                if asset_amount := order_util.get_fees_for_currency(fee, fee_asset):
-                    for delta_counter in (expected_fee_related_deltas, possible_fee_related_deltas):
-                        if delta_counter is expected_fee_related_deltas and not is_expected_fee:
-                            # when updating expected_fee_related_deltas, only account for expected fees
-                            continue
-                        if fee_asset not in delta_counter:
-                            delta_counter[fee_asset] = -asset_amount
-                        else:
-                            delta_counter[fee_asset] += -asset_amount
+        if actual_fees := order.fee:
+            if (
+                actual_fees[enums.FeePropertyColumns.IS_FROM_EXCHANGE.value] 
+                and actual_fees[enums.FeePropertyColumns.COST.value]
+            ):
+                # order fees are from exchange: add them to asset deltas as they are confirmed
+                fee_asset = actual_fees[enums.FeePropertyColumns.CURRENCY.value]
+                if fee_asset not in asset_deltas:
+                    # always substract fees
+                    asset_deltas[fee_asset] = -decimal.Decimal(str(actual_fees[enums.FeePropertyColumns.COST.value]))
+                else:
+                    asset_deltas[fee_asset] -= decimal.Decimal(str(actual_fees[enums.FeePropertyColumns.COST.value]))
+        if compute_forecasted_fees:
+            # order "probable" related deltas (account for worse case fees)
+            expected_forecasted_fees = order.get_computed_fee(use_origin_quantity_and_price=True)
+            possible_forecasted_fees = _get_other_asset_forecasted_fees(
+                order, expected_forecasted_fees, exchange_local_fees_currency_price
+            )
+            for fee_asset in (base, quote) + tuple(exchange_local_fees_currency_price):
+                for fee in (expected_forecasted_fees, ) + possible_forecasted_fees:
+                    is_expected_fee = fee is expected_forecasted_fees
+                    if asset_amount := order_util.get_fees_for_currency(fee, fee_asset):
+                        for delta_counter in (expected_fee_related_deltas, possible_fee_related_deltas):
+                            if delta_counter is expected_fee_related_deltas and not is_expected_fee:
+                                # when updating expected_fee_related_deltas, only account for expected fees
+                                continue
+                            if fee_asset not in delta_counter:
+                                delta_counter[fee_asset] = -asset_amount
+                            else:
+                                delta_counter[fee_asset] += -asset_amount
     return asset_deltas, expected_fee_related_deltas, possible_fee_related_deltas
 
-def _get_other_asset_forecasted_fees(order: order_import.Order, forecasted_fees: dict) -> dict:
+def _get_other_asset_forecasted_fees(
+    order: order_import.Order, forecasted_fees: dict, 
+    exchange_local_fees_currency_price: dict[str, dict[str, decimal.Decimal]]
+) -> tuple[dict]:
     base, quote = symbol_util.parse_symbol(order.symbol).base_and_quote()
     other_fee = copy.deepcopy(forecasted_fees)
+    base_local_fee = None
+    quote_local_fee = None
     if base_fee := order_util.get_fees_for_currency(forecasted_fees, base):
+        fee_cost = base_fee * order.origin_price
         other_fee[enums.FeePropertyColumns.CURRENCY.value] = quote
-        other_fee[enums.FeePropertyColumns.COST.value] = base_fee * order.origin_price
+        other_fee[enums.FeePropertyColumns.COST.value] = fee_cost
+        if base not in exchange_local_fees_currency_price and quote not in exchange_local_fees_currency_price:
+            for fee_currency, fee_price_by_symbol in exchange_local_fees_currency_price.items():
+                for fee_symbol, fee_price in fee_price_by_symbol.items():
+                    parsed_fee_symbol = symbol_util.parse_symbol(fee_symbol)
+                    # shared base or quote ? divive, multiply otherwise
+                    if parsed_fee_symbol.base == base or parsed_fee_symbol.quote == quote:
+                        base_local_fee = {
+                            enums.FeePropertyColumns.CURRENCY.value: fee_currency,
+                            enums.FeePropertyColumns.COST.value: fee_cost / fee_price
+                        }
+                    elif parsed_fee_symbol.base == quote or parsed_fee_symbol.quote == base:
+                        base_local_fee = {
+                            enums.FeePropertyColumns.CURRENCY.value: fee_currency,
+                            enums.FeePropertyColumns.COST.value: fee_cost * fee_price
+                        }
     elif quote_fee := order_util.get_fees_for_currency(forecasted_fees, quote):
+        fee_cost = quote_fee / order.origin_price
         other_fee[enums.FeePropertyColumns.CURRENCY.value] = base
-        other_fee[enums.FeePropertyColumns.COST.value] = quote_fee / order.origin_price
-    return other_fee
+        other_fee[enums.FeePropertyColumns.COST.value] = fee_cost
+        if base not in exchange_local_fees_currency_price and quote not in exchange_local_fees_currency_price:
+            for fee_currency, fee_price_by_symbol in exchange_local_fees_currency_price.items():
+                for fee_symbol, fee_price in fee_price_by_symbol.items():
+                    parsed_fee_symbol = symbol_util.parse_symbol(fee_symbol)
+                    # shared base or quote ? divive, multiply otherwise
+                    if parsed_fee_symbol.base == base or parsed_fee_symbol.quote == quote:
+                        quote_local_fee = {
+                            enums.FeePropertyColumns.CURRENCY.value: fee_currency,
+                            enums.FeePropertyColumns.COST.value: fee_cost / fee_price
+                        }
+                    elif parsed_fee_symbol.base == quote or parsed_fee_symbol.quote == base:
+                        quote_local_fee = {
+                            enums.FeePropertyColumns.CURRENCY.value: fee_currency,
+                            enums.FeePropertyColumns.COST.value: fee_cost * fee_price
+                        }
+    return tuple(
+        fee
+        for fee in (other_fee, base_local_fee, quote_local_fee)
+        if fee is not None
+    )
+
+
+def _get_exchange_local_fees_currency_price(orders: list[order_import.Order]) -> dict[str, dict[str, decimal.Decimal]]:
+    exchange_local_fees_currency_price = {}
+    # use given orders to get the price of the potential local fees currencies
+    # if an order trades this currency, then we can use its price to get the price of the currency
+    for order in orders:
+        for local_fees_currency in order.trader.exchange_manager.exchange.LOCAL_FEES_CURRENCIES:
+            if local_fees_currency not in exchange_local_fees_currency_price:
+                exchange_local_fees_currency_price[local_fees_currency] = {}
+            if (
+                local_fees_currency in symbol_util.parse_symbol(order.symbol).base_and_quote() 
+                and order.symbol not in exchange_local_fees_currency_price[local_fees_currency]
+            ):
+                exchange_local_fees_currency_price[local_fees_currency][order.symbol] = order.origin_price
+    return exchange_local_fees_currency_price
