@@ -217,13 +217,11 @@ async def test_get_bankruptcy_price_with_long(future_trader_simulator_with_defau
     assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side, with_mark_price=True) == decimal.Decimal(50)
     default_contract.set_current_leverage(constants.ONE_HUNDRED)
     assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side) == decimal.Decimal("99.00990099009900990099009901")
-    assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side, with_mark_price=True) == decimal.Decimal("0.9900990099009900990099009901")
+    assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side, with_mark_price=True) == decimal.Decimal('99.00990099009900990099009901')
     await position_inst.update(update_size=constants.ONE_HUNDRED,
                                mark_price=decimal.Decimal(2) * constants.ONE_HUNDRED)
     assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side) == decimal.Decimal("99.00990099009900990099009901")
-    assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side, with_mark_price=True) == decimal.Decimal("1.980198019801980198019801980")
-    assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side, with_mark_price=True) == \
-           decimal.Decimal("1.980198019801980198019801980")
+    assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side, with_mark_price=True) == decimal.Decimal("198.0198019801980198019801980")
     assert position_inst.get_bankruptcy_price(decimal.Decimal("200"), position_inst.side) == decimal.Decimal("198.0198019801980198019801980")
     assert position_inst.get_bankruptcy_price(decimal.Decimal("200"), enums.PositionSide.SHORT) \
         == decimal.Decimal("202.0202020202020202020202020")
@@ -239,7 +237,7 @@ async def test_get_bankruptcy_price_with_short(future_trader_simulator_with_defa
     assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side, with_mark_price=True) == constants.ZERO
     default_contract.set_current_leverage(constants.ONE_HUNDRED)
     assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side) == decimal.Decimal("101.0101010101010101010101010")
-    assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side, with_mark_price=True) == decimal.Decimal("1.010101010101010101010101010")
+    assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side, with_mark_price=True) == decimal.Decimal("101.0101010101010101010101010")
     await position_inst.update(update_size=constants.ONE_HUNDRED,
                                mark_price=decimal.Decimal(2) * constants.ONE_HUNDRED)
     assert position_inst.get_bankruptcy_price(position_inst.entry_price, position_inst.side) == constants.ZERO
@@ -248,7 +246,7 @@ async def test_get_bankruptcy_price_with_short(future_trader_simulator_with_defa
     position_inst.entry_price = constants.ONE_HUNDRED
     await position_inst.update(update_size=-constants.ONE_HUNDRED, mark_price=constants.ONE_HUNDRED)
     assert position_inst.get_bankruptcy_price(decimal.Decimal("20"), position_inst.side, with_mark_price=True) == \
-           decimal.Decimal("16.66666666666666666666666667")
+           decimal.Decimal("116.6666666666666666666666667")
     assert position_inst.get_bankruptcy_price(decimal.Decimal("100"), position_inst.side) == \
            decimal.Decimal("116.6666666666666666666666667")
     assert position_inst.get_bankruptcy_price(decimal.Decimal("100"), enums.PositionSide.LONG) \
@@ -401,7 +399,7 @@ async def test_update_average_exit_price_and_transactions_long(future_trader_sim
                       symbol=DEFAULT_FUTURE_SYMBOL,
                       quantity_filled=decimal.Decimal(str(5)),
                       filled_price=decimal.Decimal(str(25)))
-    position_inst.update_from_order(market_buy)
+    await position_inst.update_from_order(market_buy)
 
     # size did not reduce, exit price is still not set
     assert position_inst.already_reduced_size == constants.ZERO
@@ -415,7 +413,7 @@ async def test_update_average_exit_price_and_transactions_long(future_trader_sim
                        symbol=DEFAULT_FUTURE_SYMBOL,
                        quantity_filled=decimal.Decimal(str(5)),
                        filled_price=decimal.Decimal(str(35)))
-    position_inst.update_from_order(market_sell)
+    await position_inst.update_from_order(market_sell)
     check_created_transaction(exchange_manager_inst, decimal.Decimal("-5"), decimal.Decimal("-5"))
 
     # size reduced, exit price is updated
@@ -429,7 +427,7 @@ async def test_update_average_exit_price_and_transactions_long(future_trader_sim
                        symbol=DEFAULT_FUTURE_SYMBOL,
                        quantity_filled=decimal.Decimal(str(8)),
                        filled_price=decimal.Decimal(str(50)))
-    position_inst.update_from_order(market_sell)
+    await position_inst.update_from_order(market_sell)
     check_created_transaction(exchange_manager_inst, decimal.Decimal("-8"), decimal.Decimal("-13"))
 
     # size reduced, exit price is updated
@@ -444,7 +442,7 @@ async def test_update_average_exit_price_and_transactions_long(future_trader_sim
                       symbol=DEFAULT_FUTURE_SYMBOL,
                       quantity_filled=decimal.Decimal(str(5)),
                       filled_price=decimal.Decimal(str(75)))
-    position_inst.update_from_order(market_buy)
+    await position_inst.update_from_order(market_buy)
 
     # size did not reduce, exit price is still 42.92452830188679245283018867
     assert position_inst.already_reduced_size == decimal.Decimal("-13")
@@ -458,7 +456,7 @@ async def test_update_average_exit_price_and_transactions_long(future_trader_sim
                        symbol=DEFAULT_FUTURE_SYMBOL,
                        quantity_filled=decimal.Decimal(str(6)),
                        filled_price=decimal.Decimal(str(80)))
-    position_inst.update_from_order(market_sell)
+    await position_inst.update_from_order(market_sell)
     check_created_transaction(exchange_manager_inst, decimal.Decimal("-6"), decimal.Decimal("-19"))
 
     # size reduced, exit price is updated
@@ -496,7 +494,7 @@ async def test_update_average_exit_price_and_transactions_short(future_trader_si
                        symbol=DEFAULT_FUTURE_SYMBOL,
                        quantity_filled=decimal.Decimal(str(5)),
                        filled_price=decimal.Decimal(str(25)))
-    position_inst.update_from_order(market_sell)
+    await position_inst.update_from_order(market_sell)
     # a new fee transaction is created
     assert isinstance(get_latest_transaction(exchange_manager_inst), personal_data.FeeTransaction)
 
@@ -510,7 +508,7 @@ async def test_update_average_exit_price_and_transactions_short(future_trader_si
                       symbol=DEFAULT_FUTURE_SYMBOL,
                       quantity_filled=decimal.Decimal(str(5)),
                       filled_price=decimal.Decimal(str(20)))
-    position_inst.update_from_order(market_buy)
+    await position_inst.update_from_order(market_buy)
     check_created_transaction(exchange_manager_inst, decimal.Decimal("5"), decimal.Decimal("5"))
 
     # size reduced, exit price is updated
@@ -524,7 +522,7 @@ async def test_update_average_exit_price_and_transactions_short(future_trader_si
                       symbol=DEFAULT_FUTURE_SYMBOL,
                       quantity_filled=decimal.Decimal(str(8)),
                       filled_price=decimal.Decimal(str(18)))
-    position_inst.update_from_order(market_buy)
+    await position_inst.update_from_order(market_buy)
     check_created_transaction(exchange_manager_inst, decimal.Decimal("8"), decimal.Decimal("13"))
 
     # size reduced, exit price is updated
@@ -539,7 +537,7 @@ async def test_update_average_exit_price_and_transactions_short(future_trader_si
                        symbol=DEFAULT_FUTURE_SYMBOL,
                        quantity_filled=decimal.Decimal(str(5)),
                        filled_price=decimal.Decimal(str(19)))
-    position_inst.update_from_order(market_sell)
+    await position_inst.update_from_order(market_sell)
     # a new fee transaction is created
     assert isinstance(get_latest_transaction(exchange_manager_inst), personal_data.FeeTransaction)
 
@@ -553,7 +551,7 @@ async def test_update_average_exit_price_and_transactions_short(future_trader_si
                       symbol=DEFAULT_FUTURE_SYMBOL,
                       quantity_filled=decimal.Decimal(str(6)),
                       filled_price=decimal.Decimal(str(17)))
-    position_inst.update_from_order(market_buy)
+    await position_inst.update_from_order(market_buy)
     check_created_transaction(exchange_manager_inst, decimal.Decimal("6"), decimal.Decimal("19"))
 
     # size reduced, exit price is updated
